// This file is part of Moonfire NVR, a security camera network video recorder.
// Copyright (C) 2016-2020 The Moonfire NVR Authors
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// In addition, as a special exception, the copyright holders give
// permission to link the code of portions of this program with the
// OpenSSL library under certain conditions as described in each
// individual source file, and distribute linked combinations including
// the two.
//
// You must obey the GNU General Public License in all respects for all
// of the code used other than OpenSSL. If you modify file(s) with this
// exception, you may extend this exception to your version of the
// file(s), but you are not obligated to do so. If you do not wish to do
// so, delete this exception statement from your version. If you delete
// this exception statement from all source files in the program, then
// also delete it here.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

use failure::Error;
use structopt::StructOpt;

#[derive(StructOpt)]
pub struct Args {
    /// Timestamp(s) to translate.
    ///
    /// May be either an integer or an RFC-3339-like string:
    /// YYYY-mm-dd[THH:MM[:SS[:FFFFF]]][{Z,{+,-,}HH:MM}].
    ///
    /// Eg: 142913484000000, 2020-04-26, 2020-04-26T12:00:00:00000-07:00.
    #[structopt(required = true)]
    timestamps: Vec<String>,
}

pub fn run(args: &Args) -> Result<i32, Error> {
    for timestamp in &args.timestamps {
        let t = db::recording::Time::parse(timestamp)?;
        println!("{} == {}", t, t.0);
    }
    Ok(0)
}
